ProxyHeader

Enum ProxyHeader 

#[non_exhaustive]
pub enum ProxyHeader { Version1 { addresses: ProxyAddresses, }, Version2 { command: ProxyCommand, transport_protocol: ProxyTransportProtocol, addresses: ProxyAddresses, }, }
The PROXY header emitted at most once at the start of a new connection.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Version1

This defines the first version specification, known as the “human-readable header format” (section 2.1), and consists of (at most) 107 bytes of data on the wire.

Fields

addresses: ProxyAddresses

The addresses used to connect to the proxy.



Version2

This defines the second version specification, known as the “binary header format” (section 2.2), and consists of a dynamic amount of bytes on the wire, depending on what information the sender wishes to convey.

Fields

command: ProxyCommand

The command of this header.

transport_protocol: ProxyTransportProtocol

The protocol over which the information was transferred originally.

addresses: ProxyAddresses

The addresses used to connect to the proxy.